from django.conf.urls import include, url

from .views import refund, webhook

event_patterns = [
    url(r'^stripe/', include([
        url(r'^webhook/$', webhook, name='webhook'),
    ])),
]

urlpatterns = [
    url(r'^control/event/(?P<organizer>[^/]+)/(?P<event>[^/]+)/stripe/refund/(?P<id>\d+)/',
        refund, name='refund'),
]



from pretix.api.serializers.i18n import I18nAwareModelSerializer
from pretix.base.models import Event


class EventSerializer(I18nAwareModelSerializer):
    class Meta:
        model = Event
        fields = ('name', 'slug', 'live', 'currency', 'date_from',
                  'date_to', 'date_admission', 'is_public', 'presale_start',
                  'presale_end', 'location')



from rest_framework import viewsets

from pretix.api.serializers.event import EventSerializer
from pretix.base.models import Event


class EventViewSet(viewsets.ReadOnlyModelViewSet):
    serializer_class = EventSerializer
    queryset = Event.objects.none()
    lookup_field = 'slug'
    lookup_url_kwarg = 'event'

    def get_queryset(self):
        return self.request.organizer.events.all()
